@@ -5,7 +5,7 @@ use Mouse;
 
 # ABSTRACT: WebService::Saasu - an interface to saasu.com's RESTful accounting API using Web::API
 
-our $VERSION = '0.3'; # VERSION
+our $VERSION = '0.4'; # VERSION
 
 use XML::Simple;
 with 'Web::API';
@@ -160,7 +160,7 @@ has 'commands' => (
 
             # inventory items
             list_items => { path => 'FullInventoryItemList' },
-            get_item  => {
+            get_item   => {
                 path      => 'InventoryItem',
                 mandatory => ['id'],
             },
@@ -287,13 +287,43 @@ has 'commands' => (
                 mandatory => ['id'],
             },
 
+            # activities
+            list_activities => { path => 'ActivityList' },
+            get_activity    => { path => 'Activity' },
+            create_activity => {
+                method  => 'POST',
+                path    => 'Tasks',
+                wrapper => [ 'tasks', 'insertActivity', 'activity' ],
+                mandatory => [ 'type', 'title', ],
+            },
+            update_activity => {
+                method    => 'POST',
+                path      => 'Tasks',
+                wrapper   => [ 'tasks', 'updateActivity', 'activity' ],
+                mandatory => [ 'id', 'lastUpdatedUid', 'type', 'title', ],
+            },
+            delete_activity => {
+                path      => 'Activity',
+                method    => 'DELETE',
+                mandatory => ['id'],
+            },
+
+            # reports
+            contact_statement_report => {
+                path      => 'contactstatementreport',
+                mandatory => [ 'contactuid', 'datefrom', 'dateto' ],
+            },
+
             # tax codes
             list_tax_codes => { path => 'TaxCodeList' },
 
             # tags
             list_tags => { path => 'TagList' },
 
-            list_deleted => { path => 'DeletedEntityList' }, };
+            # deleted entities
+            list_deleted => { path => 'DeletedEntityList' },
+
+        };
     },
 );
 
@@ -306,7 +336,7 @@ sub commands {
 sub BUILD {
     my ($self) = @_;
 
-    $self->user_agent(__PACKAGE__ . ' ' . $VERSION);
+    $self->user_agent(__PACKAGE__ . ' ' . $WebService::Saasu::VERSION);
     $self->content_type('application/xml');
     $self->base_url('https://secure.saasu.com/webservices/rest/r1');
     $self->auth_type('get_params');
@@ -340,7 +370,7 @@ WebService::Saasu - WebService::Saasu - an interface to saasu.com's RESTful acco
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 SYNOPSIS
 
